==> piwigo-2.5.1.zip: piwigo/language/et_EE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Halduri häälestamine';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatiivne viis lahendada, on kopeerida üleval pool kastis oleva teksti faili "local/config/database.inc.php" (NB! fail peab sisaldama vaid selle teksti, ei midagi muud ega ühtki tühikutki)';
$lang['Basic configuration'] = 'Põhiline häälestamine';
$lang['Can\'t connect to server'] = 'Ühendumine serveriga nurjus';
$lang['Congratulations, Piwigo installation is completed'] = 'Palju õnne! Piwigo paigaldamine on valmis.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Serveriga ühendati ära, aga andmebaasiga ühendumine nurjus.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Häälestusfaili loomine ebaõnnestus ("local/config/database.inc.php").';
$lang['Database configuration'] = 'Andmebaasi häälestamine';
$lang['Database name'] = 'Andmebaasi nimi';
$lang['Database table prefix'] = 'Andmebaasi tabelinimede eesliide';
$lang['Default gallery language'] = 'Gallerii vaikimisi keel';
$lang['Download the config file'] = 'Laadi häälestusfail alla';
$lang['Hope to see you back soon.'] = 'Loodame sind varsti jälle näha.';
$lang['Host'] = 'Host';
$lang['Installation'] = 'Paigaldamine';
$lang['It appears your webhost is currently running PHP %s.'] = 'Paistab, et su serveris jooksutatakse PHP versiooni %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Seda näidetakse külastajatele ning on vajalik veebilehe haldamiseks';
$lang['Just another Piwigo gallery'] = 'Lihtsalt veel üks järjekordne Piwigo gallerii';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hoia seda salaja, sellega saad lehekülje haldurisse sisse';
$lang['PHP 5 is required'] = 'Vajatakse PHP versiooni 5';
$lang['Password ']['confirm'] = 'Kinnita parooli';
$lang['Password'] = 'Parool';
$lang['Sorry!'] = 'Vabandust!';
$lang['Start Install'] = 'Alusta paigaldamist';
$lang['Try to configure PHP 5'] = 'Proovi häälestada PHP 5';
$lang['User'] = 'Kasutaja';
$lang['Webmaster login'] = 'Veebimeistri sissepääs';
$lang['Webmaster mail address'] = 'Veebimeistri eposti aadress';
$lang['Webmaster password'] = 'Veebimeistri parool';
$lang['Welcome to my photo gallery'] = 'Tere tulemast mu fotogalleriisse';
$lang['Welcome to your new installation of Piwigo!'] = 'Tere tulemast äsja installitud Piwigosse!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Sa võid laadida häälestusfaili alla ja ise paigaldada selle oma "local/config" kaustasse.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sa peaksid küsima oma veebimajutuse teenusepakkuja käest, kas on võimalik minna üle PHP versioonile 5.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Muidugi kasuta meie foorumeid abi leidmiseks: %s';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Vajad abi? Küsi <a href="%s">Piwigo abilauast</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Sa võid teha muudatusi seadistusfailis ja pärast ümberkäivitada Piwigo.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo oskab ise proovida seadistada PHP 5, seadistades selleks .htaccess faili.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ei suutnud seadistada PHP 5 kasutamist.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Külalised võivad kasutada seda epost-aadressi et ühendust võtta administraatoriga';
$lang['also given by your host provider'] = 'samuti antud veebimajutuse teenusepakkuja poolt';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'andmebaasi tabelite nimed alustatakse selle eesliitega (see hõlpsustab tabelite korraspidamist samas andmebaasis)';
$lang['enter a login for webmaster'] = 'sisesta veebimeistri jaoks kasutajanimi';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'eposti aadress peab ühilduma malliga xxx@yyy.zzz (näiteks: keegi@siin.ee)';
$lang['please enter your password again'] = 'palun sisesta parool uuesti';
$lang['user login given by your host provider'] = 'veebimajutuse kasutajanimi';
$lang['user password given by your host provider'] = 'veebimajutuse parool';
$lang['verification'] = 'kinnitamine';
$lang['webmaster login can\'t contain characters \' or "'] = 'veebimeistri kasutajanimi ei saa sisaldada jutumärke';
?>

==> piwigo-11.5.0.zip: piwigo/language/et_EE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Halduri häälestamine';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatiivne viis lahendada, on kopeerida üleval pool kastis oleva teksti faili "local/config/database.inc.php" (NB! fail peab sisaldama vaid selle teksti, ei midagi muud ega ühtki tühikutki)';
$lang['Basic configuration'] = 'Põhiline häälestamine';
$lang['Can\'t connect to server'] = 'Ühendumine serveriga nurjus';
$lang['Congratulations, Piwigo installation is completed'] = 'Palju õnne! Piwigo paigaldamine on valmis.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Serveriga ühendati ära, aga andmebaasiga ühendumine nurjus.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Häälestusfaili loomine ebaõnnestus ("local/config/database.inc.php").';
$lang['Database configuration'] = 'Andmebaasi häälestamine';
$lang['Database name'] = 'Andmebaasi nimi';
$lang['Database table prefix'] = 'Andmebaasi tabelinimede eesliide';
$lang['Default gallery language'] = 'Gallerii vaikimisi keel';
$lang['Download the config file'] = 'Laadi häälestusfail alla';
$lang['Hope to see you back soon.'] = 'Loodame sind varsti jälle näha.';
$lang['Host'] = 'Host';
$lang['Installation'] = 'Paigaldamine';
$lang['It appears your webhost is currently running PHP %s.'] = 'Paistab, et su serveris jooksutatakse PHP versiooni %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Seda näidetakse külastajatele ning on vajalik veebilehe haldamiseks';
$lang['Just another Piwigo gallery'] = 'Lihtsalt veel üks järjekordne Piwigo gallerii';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hoia seda salaja, sellega saad lehekülje haldurisse sisse';
$lang['PHP 5 is required'] = 'Vajatakse PHP versiooni 5.2';
$lang['Password ']['confirm'] = 'Kinnita parooli';
$lang['Sorry!'] = 'Vabandust!';
$lang['Start Install'] = 'Alusta paigaldamist';
$lang['Try to configure PHP 5'] = 'Proovi häälestada PHP 5.2';
$lang['User'] = 'Kasutaja';
$lang['Welcome to my photo gallery'] = 'Tere tulemast mu fotogalleriisse';
$lang['Welcome to your new installation of Piwigo!'] = 'Tere tulemast äsja installitud Piwigosse!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Sa võid laadida häälestusfaili alla ja ise paigaldada selle oma "local/config" kaustasse.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Sa peaksid küsima oma veebimajutuse teenusepakkuja käest, kas on võimalik minna üle PHP versioonile 5.2';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Muidugi kasuta meie foorumeid abi leidmiseks: %s';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Vajad abi? Küsi <a href="%s">Piwigo abilauast</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Sa võid teha muudatusi seadistusfailis ja pärast ümberkäivitada Piwigo.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo oskab ise proovida seadistada PHP 5.2, seadistades selleks .htaccess faili.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ei suutnud seadistada PHP 5.2 kasutamist.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Külalised võivad kasutada seda epost-aadressi et ühendust võtta administraatoriga';
$lang['also given by your host provider'] = 'samuti antud veebimajutuse teenusepakkuja poolt';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'andmebaasi tabelite nimed alustatakse selle eesliitega (see hõlpsustab tabelite korraspidamist samas andmebaasis)';
$lang['enter a login for webmaster'] = 'sisesta veebimeistri jaoks kasutajanimi';
$lang['please enter your password again'] = 'palun sisesta parool uuesti';
$lang['user login given by your host provider'] = 'veebimajutuse kasutajanimi';
$lang['user password given by your host provider'] = 'veebimajutuse parool';
$lang['verification'] = 'kinnitamine';
$lang['webmaster login can\'t contain characters \' or "'] = 'veebimeistri kasutajanimi ei saa sisaldada jutumärke';
$lang['localhost or other, supplied by your host provider'] = 'localhost või teised, antud teenusepakkuja poolt';
